@@ -9,7 +9,7 @@ our @ISA        = qw(Exporter);
 our @EXPORT_OK  = qw(parse_readmem);
 our @EXPORT;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 sub bin2dec {
@@ -128,7 +128,7 @@ sub remove_comments {
     # Slurp file into $lines variable.
     my $file = shift;
     local $/ = undef;
-    open my $IN_FH, '<', $file or croak "$!";
+    open my $IN_FH, '<', $file or croak "Error: Can not open file $file: $!";
     my $lines = <$IN_FH>;
     close $IN_FH;
 
@@ -158,7 +158,7 @@ Verilog::Readmem - Parse Verilog $readmemh or $readmemb text file
 
 =head1 VERSION
 
-This document refers to Verilog::Readmem version 0.04.
+This document refers to Verilog::Readmem version 0.05.
 
 =head1 SYNOPSIS
 
@@ -223,13 +223,18 @@ the same as two widely-known, commercially-available simulators.
 
 =head1 SUBROUTINES
 
-parse_readmem
+
+=over 4
+
+=item parse_readmem
 
 Read in a Verilog $readmem format text file and return the addresses
 and data as a reference to an array of arrays.  All comments are
 stripped out.  All options to the C<parse_readmem> function must
 be passed as a single B<hash>.
 
+=back
+
 =head2 OPTIONS
 
 =over 4
@@ -288,14 +293,14 @@ blocks.  The 1st block starts at address a0 and has 3 data values.
 The 2nd block starts at address a1 and has 5 data values.
 The 3rd block starts at address a2 and has 2 data values.
 
-=head2 EXPORT
+=head1 EXPORT
 
 None by default.
 
 =head1 DIAGNOSTICS
 
 Error conditions cause the program to die using C<croak> from the
-standard C<Carp.pm> module.
+standard C<Carp> module.
 
 =head1 LIMITATIONS
 
